==> boto_wrapper_doc_20-0.0.1.tar.gz: boto_wrapper_doc_20-0.0.1/boto_wrapper_doc_pkg/boto_wrapper_doc.py <==
from getenv import env
import boto3

class sns_client:
    def create_sns_message(self, topic_id, data):
        print(topic_id)
        print(data)

ALLOWED_EXTENSIONS = set(['pdf'])

class s3_client:
    def valid_file(self, filename):
        return '.' in filename and filename.rsplit('.', 1)[1].lower() in ALLOWED_EXTENSIONS

    def upload_document(self, inp_file_name, s3_bucket_name, object_name):
        key = env["key"]
        secret = env["secret"]
        bucket_location = env["region"]
        client = boto3.client('s3',aws_access_key_id=key,aws_secret_access_key=secret)
        object_url = "https://s3-{0}.amazonaws.com/{1}/{2}".format(
            bucket_location,
            s3_bucket_name,
            object_name)

        response = client.upload_file(inp_file_name, s3_bucket_name, object_name)
        print(response)
        return response, object_url
        
class cognito_client:
    @staticmethod
    def get_user(sub):
        userpool_id = env["userpool_id"]
        request = {        
            "AttributesToGet": [ "email", "given_name", "family_name" ],
            "Filter": f"sub=\"{sub}\"",
            "UserPoolId": userpool_id
        }

        client = boto3.client('cognito-idp')
        response = client.list_users(UserPoolId = request['UserPoolId'], AttributesToGet = request['AttributesToGet'], Filter = request['Filter'])
        user = response["Users"][0]
        username = user["Username"]
        role_response = client.admin_list_groups_for_user(Username=username,UserPoolId=userpool_id)
        role = role_response["Groups"][0]["GroupName"]
        user["role"] = role
        return user

==> boto_wrapper_doc_20-0.0.2.tar.gz: boto_wrapper_doc_20-0.0.2/boto_wrapper_doc_pkg/boto_wrapper_doc.py <==
from getenv import env
import boto3

class sns_client:
    def create_sns_message(self, topic_id, data):
        print(topic_id)
        print(data)

ALLOWED_EXTENSIONS = set(['pdf'])

class s3_client:
    def valid_file(self, filename):
        return '.' in filename and filename.rsplit('.', 1)[1].lower() in ALLOWED_EXTENSIONS

    def upload_document(self, inp_file_name, s3_bucket_name, object_name):
        key = env["key"]
        secret = env["secret"]
        bucket_location = env["region"]
        client = boto3.client('s3',aws_access_key_id=key,aws_secret_access_key=secret)
        object_url = "https://s3-{0}.amazonaws.com/{1}/{2}".format(
            bucket_location,
            s3_bucket_name,
            object_name)

        response = client.upload_file(inp_file_name, s3_bucket_name, object_name)
        print(response)
        return response, object_url
        
class cognito_client:
    @staticmethod
    def get_user(sub):
        userpool_id = env["userpool_id"]
        request = {        
            "AttributesToGet": [ "email", "given_name", "family_name" ],
            "Filter": f"sub=\"{sub}\"",
            "UserPoolId": userpool_id
        }
        key = env["key"]
        secret = env["secret"]
        bucket_location = env["region"]
        client = boto3.client('cognito-idp',aws_access_key_id=key,aws_secret_access_key=secret)
        
        response = client.list_users(UserPoolId = request['UserPoolId'], AttributesToGet = request['AttributesToGet'], Filter = request['Filter'])
        user = response["Users"][0]
        username = user["Username"]
        role_response = client.admin_list_groups_for_user(Username=username,UserPoolId=userpool_id)
        role = role_response["Groups"][0]["GroupName"]
        user["role"] = role
        return user
